{
  pkgs,
  inputs,
  ...
}: {
  imports = [
    ./services/nginx.nix
    ./services/openssh.nix
    ./services/forgejo.nix
    # ./services/nextcloud.nix
    # ./services/seafile.nix
    ./services/vaultwarden.nix
    ./services/jellyfin.nix
    ./services/website.nix
    ./services/mailserver.nix
    ./services/fail2ban.nix

    ./services/auto-torrent.nix

    ./services/misc.nix

    ./modules/age.nix
    ./modules/git.nix
    ./modules/nix-settings.nix
    ./modules/zfs.nix

    (import ./modules/microvm.nix {routed = true;})
    (import ./modules/networking-shared.nix {hostname = "server";})
    (import ./modules/users.nix {main-user = "baritone";})
  ];

  boot.loader = {
    systemd-boot.enable = true;
    efi.canTouchEfiVariables = true;
    timeout = 0;
  };

  # Enable microcode updates
  hardware.enableRedistributableFirmware = true;

  programs.zsh = {
    enable = true;
    enableGlobalCompInit = true;
    shellAliases = {
      "nrb" = "sudo nixos-rebuild switch --flake /etc/nixos";
    };
  };

  programs.ssh.startAgent = true;
  programs.nano.enable = false;

  environment.systemPackages = with pkgs; [
    wget
    curl
    git
    vim

    inputs.agenix.packages."${system}".default
  ];

  environment.variables = {
    EDITOR = "vim"; # FUCK NANO
  };

  time.timeZone = "Europe/Copenhagen";

  security.sudo = {
    enable = true;
    # I know what im doing
    extraConfig = ''
      Defaults  lecture = never
    '';
  };

  programs.mtr.enable = true;
  programs.gnupg.agent.enable = true;

  system.stateVersion = "24.11";
}
